@@ -1,10 +1,12 @@
 #!/usr/bin/perl
 
+my $RCS_Id = '$Id: eps2png.pl,v 2.7 2009/05/20 13:33:19 jv Exp $ ';
+
 # Author          : Johan Vromans
 # Created On      : Tue Sep 15 15:59:04 1992
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Jan  2 19:48:11 2020
-# Update Count    : 199
+# Last Modified On: Wed May 20 15:55:08 2009
+# Update Count    : 175
 # Status          : Okay
 
 ################ Common stuff ################
@@ -13,8 +15,11 @@ use strict;
 use Getopt::Long 2.1;
 
 my $my_package = "Sciurix";
-my $my_name = "eps2png";
-our $VERSION = 2.9;
+my ($my_name, $my_version) = $RCS_Id =~ /: (.+).pl,v ([\d.]+)/;
+$my_version .= '*' if length('$Locker:  $ ') > 12;
+
+use vars qw($VERSION);
+( $VERSION ) = '$Revision: 2.7 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 ################ Program parameters ################
 
@@ -55,14 +60,6 @@ $verbose |= $trace;
 my $eps_file;
 my $err = 0;
 
-my $gv = `gs --version`;
-if ( $gv =~ /^(\d+)\.(\d+)/ ) {
-    $gv = sprintf("%03d%03d", $1, $2);
-}
-else {
-    die("Cannot fetch ghostscript version (was ghostscript installed?)\n")
-}
-
 FILE:
 foreach $eps_file ( @ARGV ) {
 
@@ -180,7 +177,6 @@ foreach $eps_file ( @ARGV ) {
     print STDERR ("Creating $out_file\n") if $verbose;
 
     my $gs0 = "gs -q -dNOPAUSE -r$res -g${width}x$height";
-    $gs0 .= " --permit-file-read=\"$eps_file\"" if $gv > "009027";
     my $gs1 = "-";
     $gs0 .= " -dTextAlphaBits=$antialias -dGraphicsAlphaBits=$antialias"
       if $antialias;
@@ -297,7 +293,7 @@ sub handle_options {
 			     'debug'	   => \$debug)
 	    && !$help;
     }
-    print STDERR ("This is $my_package [$my_name $VERSION]\n")
+    print STDERR ("This is $my_package [$my_name $my_version]\n")
 	if $ident;
     die ("Only one file argument is allowed when -output is used\n")
       if @ARGV > 1 && defined $output;
@@ -309,26 +305,26 @@ sub handle_options {
 
 sub usage {
     print STDERR <<EndOfUsage;
-This is $my_package [$my_name $VERSION]
+This is $my_package [$my_name $my_version]
 Usage: $0 [options] file [...]
 
-    --png --pngmono --pnggray --png16 --png256 --png16m --pngalpha
+    -png -pngmono -pnggray -png16 -png256 -png16m -pngalpha
                         produce PNG image
-    --jpg --jpggray --jpeg --jpeggray
+    -jpg -jpggray -jpeg -jpeggray
                         produce JPG image
-    --gif --gifmono	produce GIF image
-    --[no]mono		monochrome/colour rendition
-    --width XXX		desired with
-    --height XXX	desired height
-    --resolution XXX	resolution (default = $res)
-    --scale XXX		scaling factor
-    --antialias XX	antialias factor (must be 0, 1, 2, 4 or 8; default: 4)
-    --noantialias	no antialiasing (same as --antialias 0)
-    --[no]pbm		GIF only: [do not] convert via pbm format
-    --output XXX	output to this file (only one input file)
-    --help		this message
-    --ident		show identification
-    --verbose		verbose information
+    -gif -gifmono       produce GIF image
+    -[no]mono		monochrome/colour rendition
+    -width XXX		desired with
+    -height XXX		desired height
+    -resolution XXX	resolution (default = $res)
+    -scale XXX		scaling factor
+    -antialias XX	antialias factor (must be 0, 1, 2, 4 or 8; default: 4)
+    -noantialias	no antialiasing (same as -antialias 0)
+    -[no]pbm		GIF only: [do not] convert via pbm format
+    -output XXX		output to this file (only one input file)
+    -help		this message
+    -ident		show identification
+    -verbose		verbose information
 EndOfUsage
     exit 1;
 }
@@ -376,17 +372,17 @@ so on.
 
 =over 4
 
-=item B<--png --pngmono --pnggray --png16 --png256 --png16m --pngalpha>
+=item B<-png -pngmono -pnggray -png16 -png256 -png16m -pngalpha>
 
 Each of these options will instruct Ghostscript to use the
 corresponding bitmap generator, and supply a C<.png> default
 extension for output files.
 
-=item B<--jpg --jpggray --jpeg --jpeggray>
+=item B<-jpg -jpggray -jpeg -jpeggray>
 
 Same, but with a C<.jpg> default extension for output files.
 
-=item B<--gif --gifmono>
+=item B<-gif -gifmono>
 
 Same, but with a C<.gif> default extension for output files.
 
@@ -395,80 +391,80 @@ format due to copyright restrictions, B<eps2png> will request
 Ghostscript to produce a Portable Bitmap File (.ppm or .pbm) instead
 and run the B<ppmtogif> converter to produce the actual GIF file.
 
-=item B<--mono>
+=item B<-mono>
 
 This option will select monochrome (BW or gray) output. It forces the
 Ghostscript driver to C<pngmono>, C<jpeggray>, C<pbm>, or C<gifmono>.
 
-=item B<--nomono>
+=item B<-nomono>
 
 Produces colour images. This is the default.
 
-=item B<--width> I<NN>
+=item B<-width> I<NN>
 
 The desired width of the output image.
 
-If B<--height> is not specified, the image will be scaled proportionally.
+If B<-height> is not specified, the image will be scaled proportionally.
 
-=item B<--height> I<NN>
+=item B<-height> I<NN>
 
 The desired height of the output image.
 
-If B<--width> is not specified, the image will be scaled proportionally.
+If B<-width> is not specified, the image will be scaled proportionally.
 
-=item B<--resolution> I<NN>
+=item B<-resolution> I<NN>
 
 Specifies the resolution for the output image. This is the width, in
 pixels, of the bitmap image for an EPS image of one inch wide (72
 PostScript points).
 
-Note that for best results, use the B<--width> and B<--height> options
+Note that for best results, use the B<-width> and B<-height> options
 instead.
 
 Default value is 82, which causes the converted image to be of more
 or less the same size as the EPS image. On my screen, that is.
 
-=item B<--scale> I<NN>
+=item B<-scale> I<NN>
 
 Specify a scaling factor. This may be a fractional number.
 
 For a one-inch EPS image, the resultant bitmap image will be
 I<scale> times I<resolution>.
 
-Note that for best results, use the B<--width> and B<--height> options
+Note that for best results, use the B<-width> and B<-height> options
 instead.
 
-=item B<--antialias> I<NN>
+=item B<-antialias> I<NN>
 
 Sets the antialiasing depth. I<NN> must be 0 (no antialiasing), 1, 2,
 4, or 8. Default value is 4.
 
-=item B<--noantialias>
+=item B<-noantialias>
 
 Sets the antialiasing depth to 0.
 
-=item B<--pbm>
+=item B<-pbm>
 
 Forces GIF conversion through the PBM converters.
 
-=item B<--nopbm>
+=item B<-nopbm>
 
 Forces GIF conversion through Ghostscript.
 
-=item B<--output> I<XXX>
+=item B<-output> I<XXX>
 
 Stores the output in this file. Only one input file may be supplied if
 this option is specified.
 
-=item B<--help>
+=item B<-help>
 
 Prints a help message and exits.
 
-=item B<--ident>
+=item B<-ident>
 
 Prints the program version before doing anything else.
 
-=item B<--verbose>
+=item B<-verbose>
 
 Provides more verbose information.
 
@@ -476,7 +472,7 @@ Provides more verbose information.
 
 =head1 AUTHOR
 
-Johan Vromans, <jv@cpan.org>.
+Johan Vromans, <jvromans@squirrel.nl>.
 
 =head1 BUGS
 
@@ -488,21 +484,22 @@ listed above.
 
 The EPS should be well-behaving.
 
-Development of this program takes place on GitHub:
-https://github.com/sciurius/eps2png.
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc eps2png
-
-Please report any bugs or feature requests using the issue tracker on
-GitHub.
-
 =head1 COPYRIGHT AND DISCLAIMER
 
-This program is Copyright 1992,2008,2020 by Johan Vromans.
+This program is Copyright 1994,2008 by Johan Vromans.
+This program is free software; you can redistribute it and/or
+modify it under the terms of the Perl Artistic License or the
+GNU General Public License as published by the Free Software
+Foundation; either version 2 of the License, or (at your option) any
+later version.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+If you do not have a copy of the GNU General Public License write to
+the Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
+MA 02139, USA.
 
 =cut
